@@ -48,38 +48,12 @@ class CfnPipeline(
         id: str,
         *,
         name: str,
-        parameter_objects: typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union["ParameterObjectProperty", aws_cdk.core.IResolvable]
-            ],
-        ],
+        parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["ParameterObjectProperty", aws_cdk.core.IResolvable]]],
         activate: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         description: typing.Optional[str] = None,
-        parameter_values: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]
-                ],
-            ]
-        ] = None,
-        pipeline_objects: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]
-                ],
-            ]
-        ] = None,
-        pipeline_tags: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]
-                ],
-            ]
-        ] = None,
+        parameter_values: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]]]] = None,
+        pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]]]] = None,
+        pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]]]] = None,
     ) -> None:
         """Create a new ``AWS::DataPipeline::Pipeline``.
 
@@ -154,10 +128,7 @@ class CfnPipeline(
     @jsii.member(jsii_name="parameterObjects")
     def parameter_objects(
         self,
-    ) -> typing.Union[
-        aws_cdk.core.IResolvable,
-        typing.List[typing.Union["ParameterObjectProperty", aws_cdk.core.IResolvable]],
-    ]:
+    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["ParameterObjectProperty", aws_cdk.core.IResolvable]]]:
         """``AWS::DataPipeline::Pipeline.ParameterObjects``.
 
         see
@@ -168,12 +139,7 @@ class CfnPipeline(
     @parameter_objects.setter
     def parameter_objects(
         self,
-        value: typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union["ParameterObjectProperty", aws_cdk.core.IResolvable]
-            ],
-        ],
+        value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["ParameterObjectProperty", aws_cdk.core.IResolvable]]],
     ) -> None:
         jsii.set(self, "parameterObjects", value)
 
@@ -211,14 +177,7 @@ class CfnPipeline(
     @jsii.member(jsii_name="parameterValues")
     def parameter_values(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]]]]:
         """``AWS::DataPipeline::Pipeline.ParameterValues``.
 
         see
@@ -229,14 +188,7 @@ class CfnPipeline(
     @parameter_values.setter
     def parameter_values(
         self,
-        value: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "ParameterValueProperty"]]]],
     ) -> None:
         jsii.set(self, "parameterValues", value)
 
@@ -244,14 +196,7 @@ class CfnPipeline(
     @jsii.member(jsii_name="pipelineObjects")
     def pipeline_objects(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineObjects``.
 
         see
@@ -262,14 +207,7 @@ class CfnPipeline(
     @pipeline_objects.setter
     def pipeline_objects(
         self,
-        value: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineObjectProperty"]]]],
     ) -> None:
         jsii.set(self, "pipelineObjects", value)
 
@@ -277,12 +215,7 @@ class CfnPipeline(
     @jsii.member(jsii_name="pipelineTags")
     def pipeline_tags(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineTags``.
 
         see
@@ -293,14 +226,7 @@ class CfnPipeline(
     @pipeline_tags.setter
     def pipeline_tags(
         self,
-        value: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "PipelineTagProperty"]]]],
     ) -> None:
         jsii.set(self, "pipelineTags", value)
 
@@ -432,15 +358,7 @@ class CfnPipeline(
         def __init__(
             self,
             *,
-            attributes: typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[
-                        aws_cdk.core.IResolvable,
-                        "CfnPipeline.ParameterAttributeProperty",
-                    ]
-                ],
-            ],
+            attributes: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterAttributeProperty"]]],
             id: str,
         ) -> None:
             """
@@ -458,14 +376,7 @@ class CfnPipeline(
         @builtins.property
         def attributes(
             self,
-        ) -> typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[
-                    aws_cdk.core.IResolvable, "CfnPipeline.ParameterAttributeProperty"
-                ]
-            ],
-        ]:
+        ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterAttributeProperty"]]]:
             """``CfnPipeline.ParameterObjectProperty.Attributes``.
 
             see
@@ -550,12 +461,7 @@ class CfnPipeline(
         def __init__(
             self,
             *,
-            fields: typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.FieldProperty"]
-                ],
-            ],
+            fields: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.FieldProperty"]]],
             id: str,
             name: str,
         ) -> None:
@@ -576,12 +482,7 @@ class CfnPipeline(
         @builtins.property
         def fields(
             self,
-        ) -> typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.FieldProperty"]
-            ],
-        ]:
+        ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.FieldProperty"]]]:
             """``CfnPipeline.PipelineObjectProperty.Fields``.
 
             see
@@ -685,46 +586,12 @@ class CfnPipelineProps:
         self,
         *,
         name: str,
-        parameter_objects: typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[
-                    "CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable
-                ]
-            ],
-        ],
+        parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable]]],
         activate: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]] = None,
         description: typing.Optional[str] = None,
-        parameter_values: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[
-                        aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"
-                    ]
-                ],
-            ]
-        ] = None,
-        pipeline_objects: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[
-                        aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"
-                    ]
-                ],
-            ]
-        ] = None,
-        pipeline_tags: typing.Optional[
-            typing.Union[
-                aws_cdk.core.IResolvable,
-                typing.List[
-                    typing.Union[
-                        aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"
-                    ]
-                ],
-            ]
-        ] = None,
+        parameter_values: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]] = None,
+        pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]] = None,
+        pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::DataPipeline::Pipeline``.
 
@@ -766,14 +633,7 @@ class CfnPipelineProps:
     @builtins.property
     def parameter_objects(
         self,
-    ) -> typing.Union[
-        aws_cdk.core.IResolvable,
-        typing.List[
-            typing.Union[
-                "CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable
-            ]
-        ],
-    ]:
+    ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable]]]:
         """``AWS::DataPipeline::Pipeline.ParameterObjects``.
 
         see
@@ -802,16 +662,7 @@ class CfnPipelineProps:
     @builtins.property
     def parameter_values(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[
-                    aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]]:
         """``AWS::DataPipeline::Pipeline.ParameterValues``.
 
         see
@@ -822,16 +673,7 @@ class CfnPipelineProps:
     @builtins.property
     def pipeline_objects(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[
-                    aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineObjects``.
 
         see
@@ -842,16 +684,7 @@ class CfnPipelineProps:
     @builtins.property
     def pipeline_tags(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            aws_cdk.core.IResolvable,
-            typing.List[
-                typing.Union[
-                    aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]]:
         """``AWS::DataPipeline::Pipeline.PipelineTags``.
 
         see
